---
name: Bug report
about: Found a bug in Snippy-NG? Create an issue!
title: ''
labels: bug
assignees: Wytamma

---

**Describe the bug**
> A clear and concise description of what the bug is.


**Environment**
> Please provide your OS and Snippy-NG version. Running in conda? Use `conda list` to get your full environment. 


**Backtrace**
> If possible, please include the complete error log. 


**Additional context**
> Add any other context about the problem here.

